==> mirador-canvaslink-0.2.1.tgz: package/es/components/ShareCanvasLinkDialog.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Box from "@material-ui/core/Box";
import Button from "@material-ui/core/Button";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Dialog from "@material-ui/core/Dialog";
import DialogActions from "@material-ui/core/DialogActions";
import DialogTitle from "@material-ui/core/DialogTitle";
import makeStyles from "@material-ui/core/styles/makeStyles";
import TextField from "@material-ui/core/TextField";
import Typography from "@material-ui/core/Typography";
import Alert from "@material-ui/lab/Alert";
import ScrollIndicatedDialogContent from "mirador/dist/es/src/containers/ScrollIndicatedDialogContent";
import PropTypes from "prop-types";
import React, { useState } from "react";
import CopyToClipboard from "./CopyToClipboard";
import RightsInformation from "./RightsInformation";
import ShareButton from "./ShareButton";
var useStyles = makeStyles(function (theme) {
  return {
    actions: {
      justifyContent: "space-between",
      flexWrap: "wrap"
    },
    actionButtons: {
      flexWrap: "wrap"
    },
    alert: {
      marginBottom: theme.spacing(1)
    }
  };
});
var supportsClipboard = ("clipboard" in navigator);

var ShareCanvasLinkDialog = function ShareCanvasLinkDialog(_ref) {
  var manifestId = _ref.manifestId,
      visibleCanvases = _ref.visibleCanvases,
      label = _ref.label,
      options = _ref.options,
      rights = _ref.rights,
      t = _ref.t,
      updateOptions = _ref.updateOptions;
  var dialogOpen = options.dialogOpen,
      enabled = options.enabled,
      showRightsInformation = options.showRightsInformation,
      getCanvasLink = options.getCanvasLink;

  var _useState = useState(false),
      copiedToClipboard = _useState[0],
      setCopiedToClipboard = _useState[1];

  var _useStyles = useStyles(),
      actions = _useStyles.actions,
      actionButtons = _useStyles.actionButtons,
      alert = _useStyles.alert;

  if (!enabled || !dialogOpen || visibleCanvases.length === 0) {
    return null;
  }

  var closeDialog = function closeDialog() {
    return updateOptions(_extends({}, options, {
      dialogOpen: false
    }));
  };

  var canvasLink = getCanvasLink(manifestId, visibleCanvases);

  var getPreviewUrl = function getPreviewUrl(width) {
    var _visibleCanvases$;

    return ((_visibleCanvases$ = visibleCanvases[0]) === null || _visibleCanvases$ === void 0 ? void 0 : _visibleCanvases$.imageServiceIds[0]) + "/full/" + width + ",/0/default.jpg";
  };

  return /*#__PURE__*/React.createElement(Dialog, {
    fullWidth: true,
    maxWidth: "sm",
    scroll: "paper",
    open: dialogOpen,
    onClose: closeDialog
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    disableTypography: true
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h4"
  }, /*#__PURE__*/React.createElement(Box, {
    fontWeight: "fontWeightBold"
  }, t("canvasLink.shareLink")))), /*#__PURE__*/React.createElement(ScrollIndicatedDialogContent, {
    dividers: true
  }, copiedToClipboard && /*#__PURE__*/React.createElement(Alert, {
    className: alert,
    closeText: t("canvasLink.close"),
    onClose: function onClose() {
      return setCopiedToClipboard(false);
    },
    severity: "success"
  }, t("canvasLink.copiedToClipboard")), /*#__PURE__*/React.createElement(TextField, {
    fullWidth: true,
    InputProps: {
      endAdornment: /*#__PURE__*/React.createElement(CopyToClipboard, {
        onCopy: function onCopy() {
          navigator.clipboard.writeText(canvasLink);
          setCopiedToClipboard(true);
          setTimeout(function () {
            return setCopiedToClipboard(false);
          }, 3000);
        },
        supported: supportsClipboard,
        t: t
      }),
      readOnly: true
    },
    size: "small",
    value: canvasLink,
    variant: "outlined"
  }), showRightsInformation && /*#__PURE__*/React.createElement(RightsInformation, {
    t: t,
    rights: rights
  })), /*#__PURE__*/React.createElement(DialogActions, {
    className: actions
  }, /*#__PURE__*/React.createElement(ButtonGroup, {
    className: actionButtons
  }, ["envelope", "facebook", "pinterest", "twitter", "whatsapp"].map(function (p) {
    return /*#__PURE__*/React.createElement(ShareButton, {
      canvasLink: canvasLink,
      label: label,
      provider: p,
      thumbnailUrl: getPreviewUrl(250),
      title: t("canvasLink.share." + p)
    });
  })), /*#__PURE__*/React.createElement("div", {
    style: {
      flex: "1 0 0"
    }
  }), /*#__PURE__*/React.createElement(Button, {
    color: "primary",
    onClick: closeDialog
  }, t("canvasLink.close"))));
};

ShareCanvasLinkDialog.propTypes = process.env.NODE_ENV !== "production" ? {
  manifestId: PropTypes.string.isRequired,
  visibleCanvases: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.string.isRequired,
    imageServiceIds: PropTypes.arrayOf(PropTypes.string).isRequired
  })),
  label: PropTypes.string.isRequired,
  options: PropTypes.shape({
    dialogOpen: PropTypes.bool.isRequired,
    enabled: PropTypes.bool.isRequired,
    showRightsInformation: PropTypes.bool.isRequired,
    getCanvasLink: PropTypes.func.isRequired
  }).isRequired,
  rights: PropTypes.arrayOf(PropTypes.string),
  t: PropTypes.func.isRequired,
  updateOptions: PropTypes.func.isRequired
} : {};
ShareCanvasLinkDialog.defaultProps = {
  visibleCanvases: [],
  rights: []
};
export default ShareCanvasLinkDialog;

==> mirador-canvaslink-0.2.2.tgz: package/es/components/ShareCanvasLinkDialog.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Box from "@material-ui/core/Box";
import Button from "@material-ui/core/Button";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Dialog from "@material-ui/core/Dialog";
import DialogActions from "@material-ui/core/DialogActions";
import DialogTitle from "@material-ui/core/DialogTitle";
import makeStyles from "@material-ui/core/styles/makeStyles";
import TextField from "@material-ui/core/TextField";
import Typography from "@material-ui/core/Typography";
import Alert from "@material-ui/lab/Alert";
import ScrollIndicatedDialogContent from "mirador/dist/es/src/containers/ScrollIndicatedDialogContent";
import PropTypes from "prop-types";
import React, { useState } from "react";
import CopyToClipboard from "./CopyToClipboard";
import RightsInformation from "./RightsInformation";
import ShareButton from "./ShareButton";
var useStyles = makeStyles(function (theme) {
  return {
    actions: {
      justifyContent: "space-between",
      flexWrap: "wrap"
    },
    actionButtons: {
      flexWrap: "wrap"
    },
    alert: {
      marginBottom: theme.spacing(1)
    }
  };
});
var supportsClipboard = ("clipboard" in navigator);

var ShareCanvasLinkDialog = function ShareCanvasLinkDialog(_ref) {
  var containerId = _ref.containerId,
      manifestId = _ref.manifestId,
      visibleCanvases = _ref.visibleCanvases,
      label = _ref.label,
      options = _ref.options,
      rights = _ref.rights,
      t = _ref.t,
      updateOptions = _ref.updateOptions,
      windowId = _ref.windowId;
  var dialogOpen = options.dialogOpen,
      enabled = options.enabled,
      showRightsInformation = options.showRightsInformation,
      getCanvasLink = options.getCanvasLink;

  var _useState = useState(false),
      copiedToClipboard = _useState[0],
      setCopiedToClipboard = _useState[1];

  var _useStyles = useStyles(),
      actions = _useStyles.actions,
      actionButtons = _useStyles.actionButtons,
      alert = _useStyles.alert;

  if (!enabled || !dialogOpen || visibleCanvases.length === 0) {
    return null;
  }

  var closeDialog = function closeDialog() {
    return updateOptions(_extends({}, options, {
      dialogOpen: false
    }));
  };

  var canvasLink = getCanvasLink(manifestId, visibleCanvases);

  var getPreviewUrl = function getPreviewUrl(width) {
    var _visibleCanvases$;

    return ((_visibleCanvases$ = visibleCanvases[0]) === null || _visibleCanvases$ === void 0 ? void 0 : _visibleCanvases$.imageServiceIds[0]) + "/full/" + width + ",/0/default.jpg";
  };

  return /*#__PURE__*/React.createElement(Dialog, {
    container: document.querySelector("#" + containerId + " #" + windowId),
    fullWidth: true,
    maxWidth: "sm",
    scroll: "paper",
    open: dialogOpen,
    onClose: closeDialog
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    disableTypography: true
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h4"
  }, /*#__PURE__*/React.createElement(Box, {
    fontWeight: "fontWeightBold"
  }, t("canvasLink.shareLink")))), /*#__PURE__*/React.createElement(ScrollIndicatedDialogContent, {
    dividers: true
  }, copiedToClipboard && /*#__PURE__*/React.createElement(Alert, {
    className: alert,
    closeText: t("canvasLink.close"),
    onClose: function onClose() {
      return setCopiedToClipboard(false);
    },
    severity: "success"
  }, t("canvasLink.copiedToClipboard")), /*#__PURE__*/React.createElement(TextField, {
    fullWidth: true,
    InputProps: {
      endAdornment: /*#__PURE__*/React.createElement(CopyToClipboard, {
        onCopy: function onCopy() {
          navigator.clipboard.writeText(canvasLink);
          setCopiedToClipboard(true);
          setTimeout(function () {
            return setCopiedToClipboard(false);
          }, 3000);
        },
        supported: supportsClipboard,
        t: t
      }),
      readOnly: true
    },
    size: "small",
    value: canvasLink,
    variant: "outlined"
  }), showRightsInformation && /*#__PURE__*/React.createElement(RightsInformation, {
    t: t,
    rights: rights
  })), /*#__PURE__*/React.createElement(DialogActions, {
    className: actions
  }, /*#__PURE__*/React.createElement(ButtonGroup, {
    className: actionButtons
  }, ["envelope", "facebook", "pinterest", "twitter", "whatsapp"].map(function (p) {
    return /*#__PURE__*/React.createElement(ShareButton, {
      canvasLink: canvasLink,
      label: label,
      provider: p,
      thumbnailUrl: getPreviewUrl(250),
      title: t("canvasLink.share." + p)
    });
  })), /*#__PURE__*/React.createElement("div", {
    style: {
      flex: "1 0 0"
    }
  }), /*#__PURE__*/React.createElement(Button, {
    color: "primary",
    onClick: closeDialog
  }, t("canvasLink.close"))));
};

ShareCanvasLinkDialog.propTypes = process.env.NODE_ENV !== "production" ? {
  containerId: PropTypes.string.isRequired,
  manifestId: PropTypes.string.isRequired,
  visibleCanvases: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.string.isRequired,
    imageServiceIds: PropTypes.arrayOf(PropTypes.string).isRequired
  })),
  label: PropTypes.string.isRequired,
  options: PropTypes.shape({
    dialogOpen: PropTypes.bool.isRequired,
    enabled: PropTypes.bool.isRequired,
    showRightsInformation: PropTypes.bool.isRequired,
    getCanvasLink: PropTypes.func.isRequired
  }).isRequired,
  rights: PropTypes.arrayOf(PropTypes.string),
  t: PropTypes.func.isRequired,
  updateOptions: PropTypes.func.isRequired,
  windowId: PropTypes.string.isRequired
} : {};
ShareCanvasLinkDialog.defaultProps = {
  visibleCanvases: [],
  rights: []
};
export default ShareCanvasLinkDialog;
